#
# spec file for package libnfs
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2015 Bjørn Lie, Bryne, Norway.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname 8

Name:           libnfs
Version:        1.11.0
Release:        1.28
Summary:        Client library for accessing NFS shares over a network
License:        LGPL-2.1+ and BSD-2-Clause and GPL-3.0+
Group:          Productivity/Networking/NFS
Url:            https://github.com/sahlberg/libnfs
Source0:        https://sites.google.com/site/libnfstarballs/li/libnfs-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Package contains a library of functions for accessing NFSv2 and
NFSv3 servers from user space. It provides a low-level,
asynchronous RPC library for accessing NFS protocols, an
asynchronous library with POSIX-like VFS functions, and a
synchronous library with POSIX-like VFS functions.

%package -n libnfs%{soname}
Summary:        Client library for accessing NFS shares over a network
Group:          Productivity/Networking/NFS

%description -n libnfs%{soname}
Package contains a library of functions for accessing NFSv2 and
NFSv3 servers from user space. It provides a low-level,
asynchronous RPC library for accessing NFS protocols, an
asynchronous library with POSIX-like VFS functions, and a
synchronous library with POSIX-like VFS functions.

%package devel
Summary:        Development files for libnfs
Group:          Development/Productivity/Networking/NFS
Requires:       libnfs%{soname} = %{version}-%{release}

%description devel
The libnfs-devel package contains libraries and header files for
developing applications that use libnfs.

%package -n utils-libnfs
Summary:        Utilities for accessing NFS servers
# Handle libnfs from packman, which contained both binaries and lib
Group:          Productivity/Networking/NFS
Provides:       libnfs = %{version}-%{release}
Obsoletes:      libnfs < %{version}-%{release}

%description -n utils-libnfs
The utils-libnfs package contains simple client programs for
accessing NFS servers using libnfs.

%prep
%setup -q

%build
%configure \
	--disable-werror \
	--disable-static \
	--disable-examples
make %{?_smp_mflags}

%install
make install DESTDIR=%{buildroot} %{?_smp_mflags}
find  %{buildroot}%{_libdir} -name '*.la' -delete -print

%post -n libnfs%{soname} -p /sbin/ldconfig

%postun -n libnfs%{soname} -p /sbin/ldconfig

%files -n libnfs%{soname}
%defattr(-,root,root)
%doc README COPYING LICENCE-LGPL-2.1.txt LICENCE-BSD.txt LICENCE-GPL-3.txt
%{_libdir}/libnfs.so.*

%files devel
%defattr(-,root,root)
%{_libdir}/libnfs.so
%{_includedir}/nfsc/
%{_libdir}/pkgconfig/libnfs.pc

%files -n utils-libnfs
%defattr(-,root,root)
%{_bindir}/nfs-*
%{_mandir}/man1/nfs-*.1%{?ext_man}

%changelog
* Fri Mar 10 2017 zaitor@opensuse.org
- Update to version 1.11.0:
  + Reduce the number of memory allocations in the ZDR layer.
  + Check both seconds and nanoseconds field when validating dir
    cache.
  + Invalidate the dir cache immediately if we do something that
    would cause it to become stale, such as adding/removing objects
    from the cache.
  + Add options to enable/disable dir caching.
  + Discard readahead cache on [p]write and truncate.
  + Android fixes.
  + Windows fixes.
  + Support timeouts for sync functions.
  + Add an internal pagecache.
  + Add nfs_rewinddir(), nfs_seekdir() and nfs_telldir().
  + Fix crash in nfs_truncate().
  + Fix segfault that can trigger if we rpc_disconnect() during the
    mount.
  + Add support to bind to a specific interface (linux only).
- Pass --disable-werror to configure, needed after glibc 2.25
  update.
* Sun Aug  7 2016 olaf@aepfle.de
- Add also Release to really obsolete libnfs
* Sat Jul 23 2016 olaf@aepfle.de
- Obsolete libnfs from PMBS
* Fri Apr 22 2016 zaitor@opensuse.org
- Inital packaging, version 1.10.0.
